Learn R Programming

SpecsVerification (version 0.5-0)

CorrDiff: Calculate correlation difference between a forecast and a reference forecast, and assess uncertainty

Description

Calculate correlation difference between a forecast and a reference forecast, and assess uncertainty

Usage

CorrDiff(fcst, fcst.ref, obs, N.eff = NA, conf.level = 0.95, handle.na = "na.fail")

Arguments

fcst
vector of forecasts
fcst.ref
vector of reference forecasts
obs
vector of observations
N.eff
user-defined effective sample size to be used in hypothesis test and for confidence bounds; if NA, the length of `obs` is used after removing missing values; default: NA
conf.level
confidence level for the confidence interval; default = 0.95
handle.na
how should missing values in forecasts and observations be handled; possible values are 'na.fail' and 'only.complete.triplets'; default: 'na.fail'

Value

vector with correlation difference, one-sided p-value, and central confidence interval at the user-defined confidence level

References

Steiger (1980): Tests for comparing elements of a correlation matrix. Psychological Bulletin. http://dx.doi.org/10.1037/0033-2909.87.2.245 Zou (2007): Toward using confidence intervals to compare correlations. Psychological Methods. http://dx.doi.org/10.1037/1082-989X.12.4.399

See Also

Corr

Examples

Run this code
data(eurotempforecast)
CorrDiff(rowMeans(ens), ens[, 1], obs)

Run the code above in your browser using DataLab