Learn R Programming

SpecsVerification (version 0.5-0)

Detrend: Auxiliary function for removing trends and mean from observation vector or ensemble matrix.

Description

Detrend fits a linear function to a time-series of observations or to the time-series of ensemble means of an ensemble matrix. The linear trend is removed, and if option demean is true, the total mean is removed as well.

Usage

Detrend(x, demean = TRUE)

Arguments

x
A vector, matrix, or data.frame.
demean
logical; if true, the total mean is removed from x

Value

The function returns an object of the same dimensions as the argument `x`, but with its linear trend and (possibly) its mean removed.

Examples

Run this code
 data(eurotempforecast)
 Detrend(ens)
 Detrend(obs, demean=FALSE)

Run the code above in your browser using DataLab