Learn R Programming

SpecsVerification (version 0.5-0)

DressCrps: Calculate the Continuous Ranked Probability Score (CRPS) for a mixture of Normal distributions, for example generated by ensemble dressing

Description

Calculate the Continuous Ranked Probability Score (CRPS) for a mixture of Normal distributions, for example generated by ensemble dressing

Usage

DressCrps(dressed.ens, obs)

Arguments

dressed.ens
a list with elements `ens`, a N*R matrix representing N time instances of kernel centers, and `ker.wd`, a N*R matrix with corresponding kernel standard deviations. See function `DressEnsemble`
obs
a numeric vector of length N with real-valued observations

Value

numeric vector of length N with the CRPS values

References

Grimit et al (2006): The continuous ranked probability score for circular variables and its application to mesoscale forecast ensemble verification. Q.J.R. Meteorol. Soc. http://dx.doi.org/10.1256/qj.05.235

See Also

EnsCrps, ScoreDiff, SkillScore

Examples

Run this code
data(eurotempforecast)
dressed.ens <- DressEnsemble(ens)
mean(DressCrps(dressed.ens, obs))

Run the code above in your browser using DataLab