Learn R Programming

SpecsVerification (version 0.5-0)

DressIgn: Calculate the Logarithmic (Ignorance) Score for a mixture of Normal distributions, for example generated by ensemble dressing

Description

Calculate the Logarithmic (Ignorance) Score for a mixture of Normal distributions, for example generated by ensemble dressing

Usage

DressIgn(dressed.ens, obs)

Arguments

dressed.ens
a list with elements `ens`, a N*R matrix representing N time instances of kernel centers, and `ker.wd`, a N*R matrix with corresponding kernel standard deviations. See function `DressEnsemble`
obs
a numeric vector of length N with real-valued observations

Value

numeric vector of length N with the Ignorance score values

References

Roulston and Smith (2002) Evaluating Probabilistic Forecasts Using Information Theory, doi: 10.1175/1520-0493(2002)130<1653:epfuit>2.0.CO;2

See Also

DressEnsemble, DressCrps

Examples

Run this code
data(eurotempforecast)
d.ens <- DressEnsemble(ens)
DressIgn(d.ens, obs)

Run the code above in your browser using DataLab