Learn R Programming

SpecsVerification (version 0.5-0)

EnsBrier: Calculate the ensemble-adjusted Brier Score

Description

Calculate the ensemble-adjusted Brier Score

Usage

EnsBrier(ens, obs, R.new = NA)
FairBrier(ens, obs)

Arguments

ens
a N*R matrix representing N time instances of R-member ensemble forecasts of binary events; ens[t,r]=1 if the r-th ensemble member at time t predicted the event, otherwise ens[t,r]=0
obs
a numeric vector of length N with binary observations; obs[t]=1 if the event happens at time t, otherwise obs[t]=0
R.new
ensemble size for which the scores should be adjusted

Value

numeric vector of length N with the ensemble-adjusted Brier scores

Details

`FairBrier(ens, obs)` returns `EnsBrier(ens, obs, R.new=Inf)`

References

Ferro CAT, Richardson SR, Weigel AP (2008) On the effect of ensemble size on the discrete and continuous ranked probability scores. Meteorological Applications. doi: 10.1002/met.45

See Also

EnsRps, EnsCrps, ScoreDiff, SkillScore

Examples

Run this code
data(eurotempforecast)
mean(EnsBrier(ens.bin, obs.bin, R.new=Inf))

Run the code above in your browser using DataLab