Learn R Programming

SpecsVerification (version 0.5-0)

EnsQs: Calculate the ensemble-adjusted Quadratic Score (QS) for categorical forecasts

Description

Calculate the ensemble-adjusted Quadratic Score (QS) for categorical forecasts

Usage

EnsQs(ens, obs, R.new = NA)
FairQs(ens, obs)

Arguments

ens
a N*R matrix of integers, representing N time instances of categorical ensemble forecasts; ens[t,r] indicates the category index that the r-th ensemble member forecasts at time t
obs
a vector of length N, obs[t] is the category that occurred at time t
R.new
ensemble size for which the scores should be adjusted

Value

numeric vector of length N with the ensemble-adjusted quadratic score values

Details

`FairQs(ens, obs)` returns `EnsQs(ens, obs, R.new=Inf)`

It is assumed that the smallest class index is 1, and the largest class index is calculated by max(c(ens,obs))

References

n/a

See Also

EnsBrier, EnsRps, EnsCrps, ScoreDiff, SkillScore

Examples

Run this code
data(eurotempforecast)
EnsQs(ens.cat, obs.cat, R.new=Inf)

Run the code above in your browser using DataLab