Learn R Programming

SpecsVerification (version 0.5-0)

PlotDressedEns: Plot a series forecast distributions of dressed ensembles

Description

Plot a series forecast distributions of dressed ensembles

Usage

PlotDressedEns(dressed.ens, add = FALSE, obs = NULL, plot.ens = FALSE, plot.ker = FALSE)

Arguments

dressed.ens
An object of class `dressed.ens`. See ?DressEnsemble for details.
add
logical, default=FALSE. If TRUE, no new plotting device is created and everything is added to an existing device.
obs
A vector of length N, default=NULL. The verifying observations corresponding to the individual ensemble forecasts. If a vector of length N is provided (N = nrow(dressed.ens[["ens"]]), the values are added to the plot as markers.
plot.ens
logical, default=FALSE. If TRUE, the centers of the individual dressing kernels are indicated by markers.
plot.ker
logical, default=FALSE. If TRUE, the individual dressing kernels are plotted.

Value

none

See Also

DressEnsemble

Examples

Run this code
data(eurotempforecast)
d.ens <- DressEnsemble(ens)
PlotDressedEns(d.ens, add=FALSE, obs=obs, plot.ens=FALSE, plot.ker=TRUE)

Run the code above in your browser using DataLab