Learn R Programming

SpecsVerification (version 0.5-0)

SkillScore: Calculate a skill score and assess uncertainty

Description

Calculate a skill score and assess uncertainty

Usage

SkillScore(scores, scores.ref, N.eff = NA, score.perf = 0, handle.na = "na.fail")

Arguments

scores
vector of verification scores
scores.ref
vector of verification scores of the reference forecast, must be of the same length as `scores`
N.eff
user-defined effective sample size to be used to estimate the sampling uncertainty; if NA, the length of `scores` is used; default: NA
score.perf
a numeric constant, indicating the value that the score would assign to the perfect forecast
handle.na
how should missing values in scores vectors be handled; possible values are 'na.fail' and 'use.pairwise.complete'; default: 'na.fail'

Value

vector with skill score and its estimated standard deviation

See Also

ScoreDiff

Examples

Run this code
data(eurotempforecast)
SkillScore(EnsCrps(ens, obs), EnsCrps(ens[, 1:2], obs))

Run the code above in your browser using DataLab