Usage
ReliabilityDiagram(probs, obs, bins = 10, nboot = 500, plot = FALSE, plot.refin = TRUE, cons.probs = 0.95, attributes = FALSE, handle.na = "na.fail")
Arguments
probs
vector of N probability forecasts for the event obs=1
obs
vector of N binary observations, event/no event are coded as 0/1
bins
binning to estimate the calibration function (see Details), default: 10
nboot
number of bootstrap resamples to calculate the consistency bars, default: 500
plot
logical, whether to plot the reliability diagram, default: FALSE
plot.refin
Whether to add the frequency distribution of the forecasts to the reliability diagram. default: TRUE
cons.probs
The width of the consitency intervals. default: 0.95
attributes
locical, whether attributes lines are included in the diagram. default: FALSE
handle.na
how should missing values be handled; possible values are 'na.fail' and 'use.pairwise.complete'; default: 'na.fail'